import { __decorate, __extends, __metadata } from "tslib";
import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Store } from '@ngrx/store';
import { TextEncoder } from 'text-encoding';
import { BaseService } from './base.service';
import { E1Actions } from './store/actions';
import { UPDATE_TEXT, LIST, GET_TEXT, DOWNLOAD, UPLOAD } from './request';
var MoService = /** @class */ (function (_super) {
    __extends(MoService, _super);
    function MoService(http, store) {
        var _this = _super.call(this) || this;
        _this.http = http;
        _this.store = store;
        return _this;
    }
    MoService.prototype.clear = function () {
        this.store.dispatch(new E1Actions.ClearAction({
            moResponse: undefined
        }));
    };
    Object.defineProperty(MoService.prototype, "getTextRequest", {
        set: function (request) {
            this.moRequest = {
                type: GET_TEXT,
                request: request
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MoService.prototype, "updateTextRequest", {
        set: function (request) {
            this.moRequest = {
                type: UPDATE_TEXT,
                request: request
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MoService.prototype, "listRequest", {
        set: function (request) {
            this.moRequest = {
                type: LIST,
                request: request
            };
        },
        enumerable: true,
        configurable: true
    });
    MoService.prototype.upload = function (moRequest, fileContent) {
        var _this = this;
        moRequest.deviceName = BaseService.deviceName;
        moRequest.token = BaseService.token;
        this.store.dispatch(new E1Actions.MoRequestAction({
            moRequest: moRequest
        }));
        var conn = new XMLHttpRequest();
        conn.onreadystatechange = function () {
            if (conn.readyState === XMLHttpRequest.DONE) {
                if (conn.status === 200) {
                    _this.store.dispatch(new E1Actions.MoResponseAction({
                        moResponse: JSON.parse(conn.response)
                    }));
                }
                else {
                    _this.store.dispatch(new E1Actions.MoRequestFailedAction(conn.responseText));
                }
            }
        };
        var json = JSON.stringify(moRequest);
        var boundary = 'CelinCelinCelinCelinCelinCelinCelinCelinCelinCelinCelinCelin';
        conn.open('POST', "" + BaseService.baseUrl + UPLOAD, true);
        conn.setRequestHeader('Content-Type', "multipart/form-data;charset=UTF-8;boundary=\"" + boundary + "\"");
        var pre = new TextEncoder('utf-8').encode("\n--" + boundary + "\nContent-Type: application/json;charset=UTF-8;name=json\nContent-Transfer-Encoding: binary\nContent-Disposition: form-data; name=\"moAdd\";filename=\"json\"\n\n" + json + "\n--" + boundary + "\nContent-Type: application/octed-stream;name=\"" + moRequest.fileName + "\"\nContent-Transfer-Encoding: binary\nContent-Disposition: form-data; name=\"file\"; filename=\"" + moRequest.fileName + "\"\n\n");
        var post = new TextEncoder('utf-8').encode("\r\n--" + boundary + "--\r\n");
        var blob = new Blob([pre, fileContent, post]);
        var reader = new FileReader();
        reader.onload = function () {
            conn.send(reader.result);
        };
        reader.readAsArrayBuffer(blob);
    };
    MoService.prototype.download = function (moRequest) {
        moRequest.deviceName = BaseService.deviceName;
        moRequest.token = BaseService.token;
        this.store.dispatch(new E1Actions.MoRequestAction({
            moRequest: moRequest
        }));
        var json = JSON.stringify(moRequest);
        var conn = new XMLHttpRequest();
        conn.open('POST', "" + BaseService.baseUrl + DOWNLOAD, true);
        conn.setRequestHeader('Content-Type', 'application/json');
        conn.responseType = 'arraybuffer';
        conn.send(json);
        this.store.dispatch(new E1Actions.MoResponseAction({
            moResponse: { status: conn.status }
        }));
        return conn;
    };
    MoService.prototype.call = function (callback) {
        var _this = this;
        if (callback === void 0) { callback = {}; }
        var cb = Object.assign({}, this.defaultCallback, callback);
        this.moRequest.request.deviceName = BaseService.deviceName;
        this.moRequest.request.token = BaseService.token;
        this.store.dispatch(new E1Actions.MoRequestAction({
            moRequest: this.moRequest.request
        }));
        var json = JSON.stringify(this.moRequest.request);
        this.http.post("" + BaseService.baseUrl + this.moRequest.type, json, { headers: BaseService.headers })
            .subscribe(function (moResponse) {
            _this.store.dispatch(new E1Actions.MoResponseAction({ moResponse: moResponse }));
            cb.success(moResponse);
            cb.done();
        }, function (e) {
            _this.store.dispatch(new E1Actions.MoRequestFailedAction(e));
            cb.error(e);
            cb.done();
        });
    };
    MoService = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [HttpClient,
            Store])
    ], MoService);
    return MoService;
}(BaseService));
export { MoService };
//# sourceMappingURL=mo.service.js.map