import { initialServerState, StatusTypes } from './state';
import { E1ActionTypes } from './actions';
export function e1Reducer(state, action) {
    if (state === void 0) { state = initialServerState; }
    var requestCnt = state.requestCnt;
    switch (action.type) {
        case E1ActionTypes.CLEAR:
            return Object.assign({}, state, action.payload);
        case E1ActionTypes.RESET:
            return initialServerState;
        case E1ActionTypes.CONFIG_REQUEST:
        case E1ActionTypes.AUTH_REQUEST:
        case E1ActionTypes.CONFIG_RESPONSE:
            return Object.assign({}, state, action.payload);
        case E1ActionTypes.FORM_REQUEST:
        case E1ActionTypes.DATABROWSER_REQUEST:
        case E1ActionTypes.BATCHFORM_REQUEST:
        case E1ActionTypes.MO_REQUEST:
            requestCnt++;
            return Object.assign({}, state, {
                status: requestCnt === 0 ? StatusTypes.STATUS_READY : StatusTypes.STATUS_BUSY,
                requestCnt: requestCnt
            }, action.payload);
        case E1ActionTypes.AUTH_RESPONSE:
            return Object.assign({}, state, {
                status: StatusTypes.STATUS_READY
            }, action.payload);
        case E1ActionTypes.BATCHFORM_RESPONSE:
            requestCnt--;
            return Object.assign({}, state, {
                status: requestCnt === 0 ? StatusTypes.STATUS_READY : StatusTypes.STATUS_BUSY,
                error: '',
                requestCnt: requestCnt
            }, action.payload);
        case E1ActionTypes.MO_RESPONSE:
            var moResponse = Object.assign({}, state.moResponse, action.payload.moResponse);
            requestCnt--;
            return Object.assign({}, state, {
                status: requestCnt === 0 ? StatusTypes.STATUS_READY : StatusTypes.STATUS_BUSY,
                error: '',
                requestCnt: requestCnt,
                moResponse: moResponse
            });
        case E1ActionTypes.FORM_RESPONSE:
            var formResponse = Object.assign({}, state.formResponse, action.payload.formResponse);
            requestCnt--;
            return Object.assign({}, state, {
                status: requestCnt === 0 ? StatusTypes.STATUS_READY : StatusTypes.STATUS_BUSY,
                error: '',
                requestCnt: requestCnt,
                formResponse: formResponse
            });
        case E1ActionTypes.DATABROWSER_RESPONSE:
            var databrowserResponse = Object.assign({}, state.databrowserResponse, action.payload.databrowserResponse);
            requestCnt--;
            return Object.assign({}, state, {
                status: requestCnt === 0 ? StatusTypes.STATUS_READY : StatusTypes.STATUS_BUSY,
                error: '',
                requestCnt: requestCnt,
                databrowserResponse: databrowserResponse
            });
        case E1ActionTypes.CONFIG_REQUEST_FAIL:
        case E1ActionTypes.AUTH_REQUEST_FAIL:
            return Object.assign({}, state, {
                status: StatusTypes.STATUS_OFF,
                error: action.payload
            });
        case E1ActionTypes.FORM_REQUEST_FAIL:
        case E1ActionTypes.DATABROWSER_REQUEST_FAIL:
        case E1ActionTypes.BATCHFORM_REQUEST_FAIL:
        case E1ActionTypes.MO_REQUEST_FAIL:
            requestCnt--;
            return Object.assign({}, state, {
                status: StatusTypes.STATUS_ERROR,
                error: action.payload,
                requestCnt: requestCnt
            });
        default:
            return state;
    }
}
//# sourceMappingURL=reducer.js.map